package com.aurellem.capture.audio;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.nio.ByteBuffer;

import javax.sound.sampled.AudioFormat;
import javax.sound.sampled.AudioSystem;

import org.tritonus.sampled.file.WaveAudioOutputStream;
import org.tritonus.share.sampled.file.TDataOutputStream;
import org.tritonus.share.sampled.file.TNonSeekableDataOutputStream;

/** 
 * A SoundProcessor that sends all sound data it receives to a wav file.
 * 
 * @author Robert McIntyre
 */

public class WaveFileWriter implements SoundProcessor {

    public File targetFile;
    private WaveAudioOutputStream wao;
    private TDataOutputStream tos;
    private boolean initialized = false;
	
    public WaveFileWriter(File targetFile) 
	throws FileNotFoundException{
	tos = new TNonSeekableDataOutputStream
	    (new FileOutputStream(targetFile));
    }

    public void init(AudioFormat format){
	wao = new WaveAudioOutputStream(format,AudioSystem.NOT_SPECIFIED, tos);
    }
		
    public void process(ByteBuffer audioSamples, int numSamples, AudioFormat format) {
	audioSamples.clear();
	if (!initialized){
	    init(format);
	    initialized = true;
	}
		
	byte[] data = new byte[numSamples];
	audioSamples.get(data, 0, numSamples);
	try {wao.write(data, 0, numSamples);}
	catch (IOException e) {e.printStackTrace();}
    }

    public void cleanup() {
	try {wao.close();}
	catch (IOException e) {e.printStackTrace();}
    }


}
